<h1>snaplib</h1>
<h2>A simple data preprocessing tools.</h2>

____________________________________________

# user guide

**[Kaggle Notebook](https://www.kaggle.com/code/artyomkolas/data-preprocessing-lib/notebook?scriptVersionId=116081441)**   
<https://www.kaggle.com/code/artyomkolas/data-preprocessing-lib/notebook?scriptVersionId=116081441>


____________________________________________

# PyPi

!pip install snaplib
from snaplib.snaplib import Snaplib
sl = Snaplib()